# -*- coding: utf-8 -*-
import scrapy
import re
import os
import traceback
from yzwspider.yzw.items import YzwItem


class SchoolsSpider(scrapy.Spider):
    name = 'schools'
    allowed_domains = ['chsi.com.cn']
    start_urls = []
    firstClassSubjectIndex = {}
    st = {}
    PROJECT_ROOT = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
    custom_settings = {
        'STATS_CLASS': 'yzwspider.yzw.collector.YzwCollector',
    }

    def start_requests(self):
        self.st = {i : self.settings.attributes[i].value for i in self.settings.attributes.keys() }
        path = os.path.join(self.PROJECT_ROOT, self.settings.get('FCSI_FILE'))
        with open(path, 'r', encoding='utf-8') as f:
            self.firstClassSubjectIndex = eval(f.read())
        gen = self.__ssdm_yjxk(self.settings.get('SSDM'), self.settings.get('YJXKDM'))
        for ssdm, yjxkdm in gen:
            url =  'https://yz.chsi.com.cn/zsml/queryAction.do?ssdm={}&dwmc=&mldm={}&mlmc=&yjxkdm={}&pageno=1'\
                .format(ssdm, self.settings.get('MLDM'), yjxkdm)
            yield scrapy.Request(url, meta={'ssdm':ssdm}, callback=self.parse)

    # 爬取学校目录
    def parse(self, response):
        for tr in response.xpath('//tbody/tr'):
            try:
                schName = tr.xpath('.//a[re:test(@href,"/zsml/querySchAction.do?")]/text()').extract()[0][7:]
                url = re.sub(r'queryAction', 'querySchAction', response.url)
                url = re.sub(r'dwmc=', 'dwmc=' + schName, url)
                yield scrapy.Request(url, meta={'ssdm':response.meta['ssdm']}, callback=self.parse_school)
            except Exception as e:
                self.logger.error(traceback.format_exc())
                continue
        # 翻页
        url = self.__next_page_url(response)
        if url:
            yield scrapy.Request(url, meta={'ssdm':response.meta['ssdm']}, callback=self.parse)

    # 爬取学校页面专业信息
    def parse_school(self, response):
        majorInfo = response.css('table').css('tr')
        n = len(majorInfo)
        for i in range(1, n):
            try:
                str = majorInfo[i].css('td::text')[2].extract()
                majorCode = re.findall(r'\(.*?\)', str)[0][1:-1]
                url = 'https://yz.chsi.com.cn' + majorInfo[i].css('td')[7].css('a::attr(href)')[0].extract()
                yield scrapy.Request(url, meta={'ssdm':response.meta['ssdm']}, callback=self.parse_major)
            except Exception as e:
                self.logger.error(traceback.format_exc())
                continue
        # 翻页
        url = self.__next_page_url(response)
        if url:
            yield scrapy.Request(url, meta={'ssdm':response.meta['ssdm']}, callback=self.parse_school)

    # 爬取专业信息
    def parse_major(self, response):
        try:
            item = YzwItem()
            province = response.meta['ssdm']
            majorInfo = response.css('table')[0].css('tr')
            examRange = response.xpath('//tbody[re:test(@class,"zsml-res-items")]')
            for num in range(0,len(examRange)):
                body = examRange[num]
                item['id'] = response.url[-19:] + str(num+1).zfill(2)
                item['招生单位'] = majorInfo[0].css('td::text')[1].extract()[7:]
                item['院校特性'] = self.__getSchoolFeature(item['招生单位'])
                item['院系所'] = majorInfo[1].css('td::text')[1].extract()[5:]
                item['专业'] = majorInfo[2].css('td::text')[1].extract()
                item['研究方向'] = majorInfo[3].css('td::text')[1].extract()
                item['学习方式'] = majorInfo[2].css('td::text')[3].extract()
                item['拟招生人数'] = majorInfo[4].css('td::text')[1].extract()
                item['政治'] = re.sub(r'\s', '', body.css('td::text')[0].extract())
                item['外语'] = re.sub(r'\s', '', body.css('td::text')[2].extract())
                item['业务课一'] = re.sub(r'\s', '', body.css('td::text')[3].extract())
                item['业务课二'] = re.sub(r'\s', '', body.css('td::text')[4].extract())
                item['所在地'] = self.settings.get('PROVINCE_DICT')[province]
                item['指导老师'] = majorInfo[3].xpath('td')[3].xpath('text()').extract()
                item['指导老师'] = item['指导老师'][0] if item['指导老师'] else ''
                item['专业代码'] = item['专业'][1:7]
                item['门类'] = self.settings.get('SUBJECT_INDEX')[item['专业代码'][:2]]
                item['一级学科'] = self.firstClassSubjectIndex[item['专业代码'][:4]]
                self.logger.info(item)
                yield item
        except Exception as e:
            self.logger.error(traceback.format_exc())

    # 生成省市代码， 一级学科代码
    def __ssdm_yjxk(self, ssdm, yjxkdm):
        if yjxkdm == '' and ssdm == '':
            for province in self.settings.get('PROVINCE_LISE'):
                for key in self.firstClassSubjectIndex.keys():
                    if str(key).startswith(self.settings.get('MLDM')): yield province, key
        elif yjxkdm == '':
            for key in self.firstClassSubjectIndex.keys():
                if str(key).startswith(self.settings.get('MLDM')): yield ssdm, key
        elif ssdm == '':
            for province in self.settings.get('PROVINCE_LISE'): yield province, yjxkdm
        else:
            yield ssdm, yjxkdm

    # 判断学校性质
    def __getSchoolFeature(self, schName):
        feature = ''
        if schName in self.settings.get('LIST_211'):
            feature = '211'
            if schName in self.settings.get('LIST_985'):
                feature = '985'
        return feature

    # 获取下一页url
    def __next_page_url(self, response):
        url = ''
        page = response.xpath('//div[re:test(@class,"zsml-page-box")]/ul/li').css('a::attr(onclick)').extract()
        page = page[len(page) - 1]
        pageButtonLabel = response.xpath('//li[re:test(@class,"lip unable ")]').css('li::attr(class)').extract()
        # 非最后一页
        if pageButtonLabel == [] or pageButtonLabel == ['lip unable lip-first']:
            try:
                nextPage = re.findall(r'\(.*?\)', page)[0][1:-1]
                url = re.sub(r'pageno=\d*', 'pageno=' + nextPage, response.url)
            except Exception as e:
                self.logger.error(traceback.format_exc())
        return url




# -*- coding: utf-8 -*-
import scrapy


class YzwItem(scrapy.Item):
    id = scrapy.Field()
    招生单位 = scrapy.Field()
    院校特性 = scrapy.Field()
    院系所 = scrapy.Field()
    专业  = scrapy.Field()
    研究方向 = scrapy.Field()
    学习方式 = scrapy.Field()
    拟招生人数 = scrapy.Field()
    业务课一 = scrapy.Field()
    业务课二 = scrapy.Field()
    外语 = scrapy.Field()
    政治 = scrapy.Field()
    所在地 = scrapy.Field()
    指导老师 = scrapy.Field()
    专业代码 = scrapy.Field()
    门类 = scrapy.Field()
    一级学科 = scrapy.Field()



# -*- coding: utf-8 -*-
from scrapy.statscollectors import MemoryStatsCollector
import logging
import pprint

logger = logging.getLogger(__name__)


class YzwCollector(MemoryStatsCollector):

    def __init__(self, crawler):
        super(YzwCollector, self).__init__(crawler)

    def close_spider(self, spider, reason):
        if self._dump:
            start_time = self._stats['start_time']
            finish_time = self._stats['finish_time']
            if self._stats['finish_reason'] == 'finished':
                logger.info("""数据抓取完成, 共计 {0} 条数据，
                    程序开始时间 {1} , 结束时间 {2}, 耗时 {3} 分钟"""
                            .format(self._stats['item_scraped_count'],
                                start_time.strftime('%Y-%m-%d %H:%M:%S'),
                                finish_time.strftime('%Y-%m-%d %H:%M:%S'),
                                int((finish_time - start_time).seconds / 60))
                            )
            else:
                logger.info("异常终止:\n" + pprint.pformat(self._stats),
                        extra={'spider': spider})
        self._persist_stats(self._stats, spider)



# -*- coding: utf-8 -*-

import argparse
import os
from yzwspider.yzw.settings import PROVINCE_DICT, SUBJECT_INDEX
import yzwspider.yzw.start as start


def run():
    args = args_parse()
    start.startup(get_settings(args))


def excel_settings(args):
    prams = {}
    prams['MYSQL'] = False
    prams['EXCEL_FILE_PATH'] = args.o
    if args.all is True:
        print("爬取全部信息时请使用mysql")
        exit(0)
    return prams


def mysql_settings(args):
    prams = {}
    prams['MYSQL'] = True
    prams['HOST'] = args.host
    prams['USER'] = args.u
    prams['PASSWORD'] = args.p
    prams['PORT'] = args.port
    prams['DATABASE'] = args.db
    prams['TABLE'] = args.table
    return prams


def general_settings(args):
    prov_num = dict(zip(PROVINCE_DICT.values(), PROVINCE_DICT.keys()))
    subj_num = dict(zip(SUBJECT_INDEX.values(), SUBJECT_INDEX.keys()))
    prams = {}
    prams['SSDM'] = args.ssdm if args.all is False else ''
    prams['SSDM'] = prams['SSDM'] if not is_chinese(prams['SSDM']) else prov_num[prams['SSDM']]
    prams['MLDM'] = args.mldm if args.all is False else ''
    prams['MLDM'] = prams['MLDM'] if not is_chinese(prams['MLDM']) else subj_num[prams['MLDM']]
    prams['YJXKDM'] = args.yjxk if args.all is False else ''
    prams['LOG_LEVEL'] = args.lglevel
    if not args.log:
        prams['LOG_FILE'] = None
    else:
        print("日志文件将输出至当前目录.")
    return prams


def get_settings(args):
    settings = {}
    settings.update(args.func(args))
    settings.update(general_settings(args))
    return settings


def args_parse():
    usage = """yzwspider [-h] [-ssdm] [-mldm] [-yjxk] [-lglevel] [--all] [--log] 输出目标 [其他参数]
              \t例, yzwspider -ssdm 11 -yjxk 0812 excel -o 文件输出路径
              \t    yzwspider -ssdm 11 -yjxk 0812 mysql -p 你的密码 -db 数据库 -table 数据表
              \t    具体参数以及默认值请使用 yzwspider 输出目标 -h 查看
              """
    parser = argparse.ArgumentParser(prog='yzwspider', usage=usage)
    parser.add_argument('-ssdm', help='省市代码(默认11)，中文名称也可.', choices=[*PROVINCE_DICT.keys(), *PROVINCE_DICT.values()], metavar='省市代码', default='11')
    parser.add_argument('-mldm', help="门类代码(默认01)", choices=[*SUBJECT_INDEX.keys(), *SUBJECT_INDEX.values()], metavar='门类代码', default='01')
    parser.add_argument('-yjxk', help='一级学科代码(默认0101)', metavar='一级学科代码', default='0101')
    parser.add_argument('-lglevel', help='日志等级(INFO)', metavar='日志等级', default='INFO')
    parser.add_argument('--all', help='爬取全国所有专业并输出到mysql',  action='store_true')
    parser.add_argument('--log', help='保存日志文件', action='store_true')
    sub_parser = parser.add_subparsers(metavar='输出目标', required=True)
    sub_parse(sub_parser)
    args = parser.parse_args()
    return args


def sub_parse(subparser):
    mysql_parse(subparser)
    excel_parse(subparser)


def excel_parse(subparser):
    parser_excel = subparser.add_parser("excel", help="输出到excel")
    parser_excel.add_argument('-o', help='输出路径(默认输出至当前目录)', metavar='输出路径', default=os.getcwd())
    parser_excel.set_defaults(func=excel_settings)


def mysql_parse(subparser):
    parser_mysql = subparser.add_parser("mysql", help="输出到mysql")
    parser_mysql.add_argument('-host', help='主机地址(localhost)', metavar='主机地址', default='localhost')
    parser_mysql.add_argument('-port', help='端口(3306)', metavar='端口号', type=int, default=3306)
    parser_mysql.add_argument('-u', help='用户名(root)', metavar='用户名', default='root')
    parser_mysql.add_argument('-p', help='密码(默认空)', metavar='密码', default='')
    parser_mysql.add_argument('-db', help='数据库(yanzhao)', metavar='数据库名', default='yanzhao')
    parser_mysql.add_argument('-table', help='数据表(major)', metavar='数据表名', default='major')
    parser_mysql.set_defaults(func=mysql_settings)


def is_chinese(word):
    for ch in word:
        if '\u4e00' <= ch <= '\u9fff':
            return True
    return False


# -*- coding: utf-8 -*-
import pymysql
import xlwt
import logging
import os
from twisted.enterprise import adbapi
import traceback
from yzwspider.yzw.items import YzwItem

logger = logging.getLogger("YzwPipeline")


class YzwPipeline(object):
    def __init__(self, pool, settings):
        self.dbpool = pool
        self.settings = settings
        self.excelstyle = self.getExcelStyle()
        excel_path = os.getcwd() if settings.get("EXCEL_FILE_PATH") == '.' else settings.get("EXCEL_FILE_PATH")
        excel_file = settings.get("EXCEL_FILE_NAME") + '.xls'
        self.excelFile = os.path.join(excel_path, excel_file)

    @classmethod
    def from_settings(cls, settings):
        params = dict(
            host=settings.get("HOST"),
            port=settings.get("PORT"),
            db=settings.get("DATABASE"),
            user=settings.get("USER"),
            passwd=settings.get("PASSWORD"),
            charset=settings.get("CHARSET"),
            cursorclass=pymysql.cursors.DictCursor
        )
        db_connect_pool = None
        if settings.get("MYSQL"):
            YzwPipeline.__test_mysql_settings(**params)
            db_connect_pool = adbapi.ConnectionPool('pymysql', **params)
        obj = cls(db_connect_pool, settings)
        return obj

    def _create_table(self, txn):
        try:
            sql = "DROP TABLE IF EXISTS `{0}`".format(self.settings.get("TABLE"))
            re = txn.execute(sql)
            sql = self.settings.get("CREATE_TEBLE_SQL").format(self.settings.get("TABLE"))
            re = txn.execute(sql)
            logger.info("创建表:'%s'成功." % self.settings.get('TABLE'))
        except Exception as e:
            logger.critical(traceback.format_exc())

    def open_spider(self, spider):
        if self.dbpool:
            obj = self.dbpool.runInteraction(self._create_table)
        else:
            self.newExcelFile()

    def close_spider(self, spider):
        try:
            if self.dbpool:
                self.dbpool.close()
                logger.info("数据已存储于数据库" + self.settings.get("DATABASE") + "， 表：" + self.settings.get("TABLE"))
            else:
                self.wbk.save(self.excelFile)
                logger.info("excel文件已存储于 " + self.excelFile)
        except Exception as e:
            logger.error(traceback.format_exc())

    def process_item(self, item, spider):
        try:
            if self.dbpool:
                self.process_mysql(item)
            else:
                self.process_excel(item)
        except Exception as e:
            logger.critical(traceback.format_exc())

    def process_mysql(self, item):
        result = self.dbpool.runInteraction(self.insert, item)
        # 给result绑定一个回调函数，用于监听错误信息
        result.addErrback(self.error)

    def insert(self, cursor, item):
        insert_sql = "insert into {0} (`id`, `招生单位`, `院校特性`, `院系所`, `专业`,`研究方向`,`学习方式`, `拟招生人数`" \
                     ", `业务课一`, `业务课二`, `外语`, `政治`, `所在地`, `专业代码`,`指导老师`, `门类`, `一级学科` ) " \
                     "VALUES ('{1}','{2}','{3}','{4}','{5}','{6}','{7}','{8}','{9}','{10}','{11}','{12}','{13}','{14}', '{15}', '{16}','{17}')" \
            .format(self.settings.get('TABLE'), item['id'], item['招生单位'], item['院校特性'], item['院系所'], item['专业'],
                    item['研究方向'], item['学习方式'], item['拟招生人数'],
                    item['业务课一'], item['业务课二'], item['外语'], item['政治'], item['所在地'], item['专业代码'], item['指导老师'],
                    item['门类'], item['一级学科'])
        cursor.execute(insert_sql)

    def error(self, reason):
        # 跳过主键重复error
        if reason.value.args[0] != 1062:
            logger.error("insert to database err: -------------\n" + reason.getErrorMessage() + "\n" + str(
                reason.getTraceback()))

    def process_excel(self, item):
        flag = False if (self.row & 1 == 0) else True
        style = xlwt.XFStyle()
        if flag:
            style = self.excelstyle
        else:
            style = xlwt.XFStyle()
            alignment = xlwt.Alignment()
            alignment.horz = xlwt.Alignment.HORZ_CENTER
            style.alignment = alignment
        for i in range(0, YzwItem.fields.__len__()):
            ret = self.sheet.write(self.row, i, item[self.list[i]], style)
        self.row += 1

    def getExcelStyle(self):
        style = xlwt.XFStyle()
        pattern = xlwt.Pattern()
        pattern.pattern = xlwt.Pattern.SOLID_PATTERN
        pattern.pattern_fore_colour = 42
        style.pattern = pattern
        borders = xlwt.Borders()
        borders.top = 1
        borders.bottom = 1
        borders.top_colour = 17
        borders.bottom_colour = 17
        style.borders = borders
        alignment = xlwt.Alignment()
        alignment.horz = xlwt.Alignment.HORZ_CENTER
        style.alignment = alignment
        return style

    def getExcelTitleStyle(self):
        style = xlwt.XFStyle()
        pattern = xlwt.Pattern()
        pattern.pattern = xlwt.Pattern.SOLID_PATTERN
        pattern.pattern_fore_colour = 17
        style.pattern = pattern
        fnt = xlwt.Font()
        fnt.name = u'黑体'
        fnt.height = 0X00D9
        fnt.colour_index = 1
        fnt.bold = True
        style.font = fnt
        alignment = xlwt.Alignment()
        alignment.horz = xlwt.Alignment.HORZ_CENTER
        style.alignment = alignment
        return style

    def newExcelFile(self):
        self.wbk = xlwt.Workbook()
        self.sheet = self.wbk.add_sheet('Sheet1')
        self.row = 1
        self.sheet.col(0).width = 3000
        self.sheet.col(1).width = 8000
        self.sheet.col(2).width = 3000
        self.sheet.col(3).width = 10000
        self.sheet.col(4).width = 7000
        self.sheet.col(5).width = 10000
        self.sheet.col(6).width = 7000
        self.sheet.col(7).width = 3000
        self.sheet.col(8).width = 5000
        self.sheet.col(9).width = 11000
        self.sheet.col(10).width = 4000
        self.sheet.col(11).width = 7000
        self.sheet.col(12).width = 2000
        self.sheet.col(13).width = 2000
        self.sheet.col(14).width = 2000
        self.sheet.col(15).width = 2000
        self.sheet.col(16).width = 6000
        self.list = ['id', '招生单位', '院校特性', '院系所', '专业', '研究方向', '学习方式', '拟招生人数'
            , '业务课一', '业务课二', '外语', '政治', '所在地', '专业代码', '指导老师', '门类', '一级学科']
        style = self.getExcelTitleStyle()
        for i in range(0, YzwItem.fields.__len__()):
            self.sheet.write(0, i, self.list[i], style)

    @staticmethod
    def __test_mysql_settings(**params):
        try:
            db = pymysql.connect(**params)
            db.close()
        except Exception as e:
            logger.critical(str(e))
            os._exit(1)



#!/usr/bin/python
from twisted.internet import reactor, defer
from scrapy.crawler import CrawlerRunner
from scrapy.utils.project import get_project_settings
from yzwspider.yzw.spiders import schools, subjects
from scrapy.utils.log import configure_logging
import os

def startup(my_settings={}):
    os.environ.setdefault('SCRAPY_SETTINGS_MODULE', 'yzwspider.yzw.settings')
    settings = get_project_settings()
    for key, value in my_settings.items():
        settings.attributes[key].value = value
    configure_logging(settings)
    runner = CrawlerRunner(settings)

    @defer.inlineCallbacks
    def crawl():
        yield runner.crawl(subjects.SubjectsSpider)
        yield runner.crawl(schools.SchoolsSpider)
        reactor.stop()

    crawl()
    reactor.run()


if __name__ == '__main__':
    startup()



# -*- coding: utf-8 -*-
import scrapy
import traceback
import os

"""
    获取一级学科目录并存储到文件 mySettings.FCSI_File 
    格式:{ 代码 : 名称 }
"""


class SubjectsSpider(scrapy.Spider):
    name = 'subjects'
    PROJECT_ROOT = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
    custom_settings = {
        'ITEM_PIPELINES': None,
    }

    def start_requests(self):
        url = 'https://yz.chsi.com.cn/zsml/pages/getZy.jsp'
        yield scrapy.Request(url, callback=self.parse)

    def parse(self, response):
        try:
            list = eval(response.text)
            firstClassSubjectIndex = {item['dm']: item['mc'] for item in list}
            path = os.path.join(self.PROJECT_ROOT, self.settings.get('FCSI_FILE'))
            with open(path, 'w', encoding='utf-8') as f:
                f.write(str(firstClassSubjectIndex))
            self.logger.info("一级学科目录抓取完成.")
        except Exception as e:
            self.logger.error(traceback.format_exc())



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
   
setuptools.setup(
    name="yzwspider",
    version="0.1.4",
    author="Hthing",
    author_email="hxcnly@gmail.com",
    description="A web spider for Chinese graduate student examination catalogue.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Hthing/yzw/tree/master/",
    license = "MIT Licence",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
    install_requires = ["xlwt", 'pymysql', 'scrapy'] ,
    package_data = {
        'yzwspider': [ 'scrapy.cfg'],
    },
)


# -*- coding: utf-8 -*-


BOT_NAME = 'yzw'
SPIDER_MODULES = ['yzwspider.yzw.spiders']
USER_AGENT = 'Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2228.0 Safari/537.36'
CONCURRENT_REQUESTS = 32
ITEM_PIPELINES = {
    'yzwspider.yzw.pipelines.YzwPipeline': 300,
}

# 日志级别与输出路径
LOG_LEVEL = 'INFO'
LOG_FILE = 'log.txt'



SSDM = '11'
MLDM = '01'
YJXKDM = '0101'

# MYSQL
MYSQL = False
HOST = 'localhost'
USER = 'root'
PASSWORD = ''
PORT = 3306
DATABASE = 'yanzhao'
TABLE = 'major'
CHARSET = 'utf8'
# EXCEL
EXCEL_FILE_NAME = "研招网专业信息"
EXCEL_FILE_PATH = "."



# 固定内容
FCSI_FILE = 'first_class_subject_index.txt'
PROVINCE_LISE = ['11', '12', '13', '14', '15', '21', '22', '23', '31', '32', '33', '34', '35', '36', '37',
                '41', '42', '43', '44', '45', '46', '50', '51', '52', '53', '54', '61', '62', '63', '64', '65', '71',
                '81', '82']
PROVINCE_DICT = {'35': '福建', '21': '辽宁', '51': '四川', '34': '安徽', '63': '青海', '42': '湖北', '64': '宁夏', '33': '浙江', '46': '海南',
        '82': '台湾', '61': '陕西', '37': '山东', '41': '河南', '13': '河北', '45': '广西', '54': '西藏', '14': '山西', '81': '澳门',
        '36': '江西', '52': '贵州', '50': '重庆', '44': '广东', '32': '江苏', '53': '云南', '71': '香港', '11': '北京', '31': '上海',
        '23': '黑龙江', '62': '甘肃', '22': '吉林', '65': '新疆', '43': '湖南', '15': '内蒙古', '12': '天津'}
LIST_985 = ["北京大学", "清华大学", "中国科学技术大学", "南京大学", "复旦大学", "上海交通大学", "西安交通大学", "浙江大学", "哈尔滨工业大学", "北京理工大学", "南开大学", "天津大学",
            "东南大学", "武汉大学", "华中科技大学", "吉林大学", "厦门大学", "山东大学", "中国海洋大学", "湖南大学", "中南大学", "大连理工大学", "北京航空航天大学", "重庆大学",
            "四川大学", "电子科技大学", "中山大学", "华南理工大学", "兰州大学", "西北工业大学", "东北大学", "同济大学", "北京师范大学", "中国人民大学", "中国农业大学",
            "国防科技大学", "中央民族大学", "华东师范大学", "西北农林科技大学"]
LIST_211 = ["北京大学", "中国人民大学", "清华大学", "北京交通大学", "北京工业大学", "北京航空航天大学", "北京理工大学", "北京科技大学", "北京化工大学", "北京邮电大学", "中国农业大学",
            "北京林业大学", "北京中医药大学", "北京师范大学", "北京外国语大学", "中国传媒大学", "中央财经大学", "对外经济贸易大学", "北京体育大学", "中央音乐学院", "中央民族大学",
            "中国政法大学", "华北电力大学", "华北电力大学(保定)", "南开大学", "天津大学", "天津医科大学", "河北工业大学", "太原理工大学", "内蒙古大学", "辽宁大学", "大连理工大学",
            "东北大学", "大连海事大学", "吉林大学", "延边大学", "东北师范大学", "哈尔滨工业大学", "哈尔滨工程大学", "东北农业大学", "东北林业大学", "复旦大学", "同济大学",
            "上海交通大学", "华东理工大学", "东华大学", "华东师范大学", "上海外国语大学", "上海财经大学", "上海大学", "第二军医大学", "南京大学", "苏州大学", "东南大学",
            "南京航空航天大学", "南京理工大学", "中国矿业大学", "中国矿业大学(北京)", "河海大学", "江南大学", "南京农业大学", "中国药科大学", "南京师范大学", "浙江大学", "安徽大学",
            "中国科学技术大学", "合肥工业大学", "厦门大学", "福州大学", "南昌大学", "山东大学", "中国海洋大学", "中国石油大学", "中国石油大学(华东)", "中国石油大学(北京)",
            "郑州大学", "武汉大学", "华中科技大学", "中国地质大学", "中国地质大学(北京)", "中国地质大学(武汉)", "武汉理工大学", "华中农业大学", "华中师范大学", "中南财经政法大学",
            "湖南大学", "中南大学", "湖南师范大学", "国防科学技术大学", "中山大学", "暨南大学", "华南理工大学", "华南师范大学", "广西大学", "海南大学", "四川大学", "西南交通大学",
            "电子科技大学", "四川农业大学", "西南财经大学", "重庆大学", "西南大学", "贵州大学", "云南大学", "西藏大学", "西北大学", "西安交通大学", "西北工业大学",
            "西安电子科技大学", "长安大学", "西北农林科技大学", "陕西师范大学", "第四军医大学", "兰州大学", "青海大学", "宁夏大学", "新疆大学", "石河子大学"]
SUBJECT_INDEX = {'01': '哲学', '02': '经济学', '03': '法学', '04': '教育学', '05': '文学', '06': '历史学', '07': '理学',
                '08': '工学', '09': '农学', '10': '医学', '11': '军事学', '12': '管理学', '13': '艺术学'}

CREATE_TEBLE_SQL = "CREATE TABLE `{0}` (" \
                   "`id` char(21) PRIMARY KEY,`招生单位` varchar(40) NOT NULL," \
                   "`院校特性` varchar(10) DEFAULT NULL," \
                   "`院系所` varchar(40) DEFAULT NULL," \
                   "`专业` varchar(40) DEFAULT NULL," \
                   "`研究方向` TINYTEXT DEFAULT NULL," \
                   "`学习方式` varchar(30) DEFAULT NULL," \
                   "`拟招生人数` varchar(40) DEFAULT NULL," \
                   "`业务课一` varchar(40) DEFAULT NULL," \
                   "`业务课二` varchar(40) DEFAULT NULL," \
                   "`外语` varchar(40) DEFAULT NULL," \
                   "`政治` varchar(40) DEFAULT NULL," \
                   "`所在地` varchar(30) DEFAULT NULL," \
                   "`指导老师` TINYTEXT DEFAULT NULL," \
                   "`专业代码` varchar(10) DEFAULT NULL," \
                   "`门类` varchar(20) DEFAULT NULL," \
                   "`一级学科` varchar(40) DEFAULT NULL)" \
                   " ENGINE=MyISAM DEFAULT CHARSET=utf8"